<?php

namespace Drupal\materialize_datetime_picker\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures Materialize DateTime Picker settings.
 */
class MaterializeDateTimeConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'materialize_datetime_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['materialize_datetime_picker.site_config_datetime'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('materialize_datetime_picker.site_config_datetime')->get("materialize_datetime_data");

    $form['date_type_format'] = [
      '#type' => 'select',
      '#title' => $this->t('Date type'),
      '#options' => [
        'date' => $this->t('Date only'),
        'datetime' => $this->t('Date and time'),
      ],
      '#default_value' => $config['date_type_format'] ?? 'date',
      '#required' => TRUE,
    ];

    $form['fields_date_only'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Specific field id to show date only'),
      '#description' => $this->t('Comma-separated field IDs. Overrides above setting.'),
      '#default_value' => $config['fields_date_only'] ?? '',
    ];

    $form['fields_datetime_only'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Specific field id to show both date and time'),
      '#description' => $this->t('Comma-separated field IDs. Overrides above setting.'),
      '#default_value' => $config['fields_datetime_only'] ?? '',
    ];

    $form['hour_format'] = [
      '#type' => 'select',
      '#title' => $this->t('Hours Format'),
      '#options' => [
        '12' => '12 Hours',
        '24' => '24 Hours',
      ],
      '#default_value' => $config['hour_format'] ?? '24',
    ];

    $form['allow_times'] = [
      '#type' => 'select',
      '#title' => $this->t('Minutes granularity'),
      '#options' => [
        '5' => $this->t('5 minutes'),
        '10' => $this->t('10 minutes'),
        '15' => $this->t('15 minutes'),
        '30' => $this->t('30 minutes'),
        '60' => $this->t('60 minutes'),
      ],
      '#default_value' => $config['allow_times'] ?? '10',
    ];

    $days = [
      '1' => $this->t('Monday'),
      '2' => $this->t('Tuesday'),
      '3' => $this->t('Wednesday'),
      '4' => $this->t('Thursday'),
      '5' => $this->t('Friday'),
      '6' => $this->t('Saturday'),
      '7' => $this->t('Sunday'),
    ];

    $form['disable_days'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Disable specific days in week'),
      '#options' => $days,
      '#default_value' => $config['disable_days'] ?? [],
    ];

    $form['week_start'] = [
      '#type' => 'radios',
      '#title' => $this->t('Select start week'),
      '#options' => $days,
      '#default_value' => $config['week_start'] ?? '1',
    ];

    $form['exclude_date'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Disable specific dates from calendar'),
      '#description' => $this->t('Format: YYYY-MM-DD, comma-separated (e.g., 2024-03-15,2024-12-25).'),
      '#default_value' => $config['exclude_date'] ?? '',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $postData = [];
    $postData['date_type_format'] = $form_state->getValue('date_type_format');
    $postData['fields_date_only'] = $form_state->getValue('fields_date_only');
    $postData['fields_datetime_only'] = $form_state->getValue('fields_datetime_only');
    $postData['hour_format'] = $form_state->getValue('hour_format');
    $postData['allow_times'] = $form_state->getValue('allow_times');
    $postData['disable_days'] = $form_state->getValue('disable_days');
    $postData['week_start'] = $form_state->getValue('week_start');
    $postData['exclude_date'] = $form_state->getValue('exclude_date');
    $this->config('materialize_datetime_picker.site_config_datetime')
      ->set('materialize_datetime_data', $postData)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
